## storage

### client

38% implemented

- [ ] batch
- [x] bucket
- [ ] create_anonymous_client
- [x] create_bucket
- [ ] create_hmac_key
- [ ] download_blob_to_file
- [x] get_bucket
- [ ] get_hmac_key_metadata
- [ ] get_service_account_email
- [ ] list_blobs
- [x] list_buckets
- [ ] list_hmac_keys
- [x] lookup_bucket

### bucket

12% implemented

- [ ] acl
- [ ] add_lifecycle_delete_rule
- [ ] add_lifecycle_set_storage_class_rule
- [ ] blob
- [ ] clear_lifecyle_rules
- [x] client
- [ ] configure_website
- [ ] copy_blob
- [ ] cors
- [x] create
- [ ] default_event_based_hold
- [ ] default_kms_key_name
- [ ] default_object_acl
- [ ] delete
- [ ] delete_blob
- [ ] delete_blobs
- [ ] disable_logging
- [ ] disable_website
- [ ] enable_logging
- [ ] etag
- [x] exists
- [x] from_string
- [ ] generate_signed_url
- [ ] generate_upload_policy
- [x] get_blob
- [ ] get_iam_policy
- [ ] get_logging
- [ ] iam_configuration
- [ ] id
- [ ] labels
- [ ] lifecycle_rules
- [ ] list_blobs
- [ ] list_notifications
- [ ] location
- [ ] location_type
- [ ] lock_retention_policy
- [ ] make_private
- [ ] make_public
- [ ] notification
- [ ] owner
- [ ] patch
- [x] path
- [ ] path_helper
- [ ] project_number
- [ ] reload
- [ ] rename_blob
- [ ] requester_pays
- [ ] retention_period
- [ ] retention_policy_effective_time
- [ ] retention_policy_locked
- [ ] self_link
- [ ] set_iam_policy
- [ ] storage_class
- [ ] test_iam_permissions
- [ ] time_created
- [ ] update
- [x] user_project
- [ ] versioning_enabled

### blob

0% implemented

- [ ] acl
- [ ] bucket
- [ ] cache_control
- [ ] chunk_size
- [ ] client
- [ ] component_count
- [ ] compose
- [ ] content_disposition
- [ ] content_encoding
- [ ] content_language
- [ ] content_type
- [ ] crc32c
- [ ] create_resumable_upload_session
- [ ] delete
- [ ] download_as_string
- [ ] download_to_file
- [ ] download_to_filename
- [ ] etag
- [ ] event_based_hold
- [ ] exists
- [ ] from_string
- [ ] generate_signed_url
- [ ] generation
- [ ] get_iam_policy
- [ ] id
- [ ] kms_key_name
- [ ] make_private
- [ ] make_public
- [ ] md5_hash
- [ ] media_link
- [ ] metadata
- [ ] metageneration
- [ ] owner
- [ ] patch
- [ ] path
- [ ] path_helper
- [ ] public_url
- [ ] reload
- [ ] retention_expiration_time
- [ ] rewrite
- [ ] self_link
- [ ] set_iam_policy
- [ ] size
- [ ] storage_class
- [ ] temporary_hold
- [ ] test_iam_permissions
- [ ] time_created
- [ ] time_deleted
- [ ] update
- [ ] update_storage_class
- [ ] updated
- [ ] upload_from_file
- [ ] upload_from_filename
- [ ] upload_from_string
- [ ] user_project
